#
# spec file for package gxine
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gxine
Summary:        GTK-based GUI for xine libraries
Version:        0.5.910
Release:        1699.2.pm.4
Url:            http://www.xine-project.org/home
Source0:        gxine-%{version}.tar.xz
Patch1:         gxine-0.5.910-reproducible.diff
License:        GPL-2.0
Group:          Productivity/Multimedia/Video/Players
Recommends:     gxine-lang = %{version}-%{release}
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  libtool
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libxine)
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(lirc)
BuildRequires:  pkgconfig(nspr)
BuildRequires:  pkgconfig(mozjs185)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  pkgconfig(xaw7)
BuildRoot:      %{_tmppath}/%{name}-%{version}-buildroot

%description
This is a GTK+ based GUI for the libxine video player library.
It provides gxine, a  media player that can play all the audio/video formats
that libxine supports. Currently, this includes MPEG1/2, some AVI and
Quicktime files, some network streaming methods and disc based media (VCD,
SVCD, DVD).
A more complete list can be found on http://xinehq.de/

Most DVDs on the market today are play-protected by the Content Scrambling
System (CSS). libxine does not provide any code to descramble those DVDs,
because of legal uncertainties. If you still want to play those DVDs, you'll
need a CSS decryption library like libdvdcss that is supported by libxine.

%package browser-plugin
Summary:        Gxine browser plugin
Group:          Productivity/Multimedia/Video/Players
Requires:       %{name} = %{version}-%{release}

%description browser-plugin
Browser plugin for mozilla and other browsers using the same plugin infrastructure.

%lang_package

%prep
%autosetup -p1

%build
./autogen.sh noconfig
export CPPFLAGS="%optflags"
%configure \
  --with-gtk3 \
  --with-logo-format=image \
  --with-gudev \
  --with-browser-plugin \
  --disable-integration-wizard \
  --enable-watchdog \
  --disable-own-playlist-parsers \
  --disable-deprecated

%__make %{?jobs:-j %jobs}

%install
%{makeinstall}
mkdir %{buildroot}/%{_libdir}/browser-plugins
mv %{buildroot}%{_libdir}/gxine/gxineplugin.so %{buildroot}%{_libdir}/browser-plugins/
rm -rf %{buildroot}%{_libdir}/gxine

%suse_update_desktop_file -r gxine AudioVideo Player Video

%find_lang gxine
%find_lang gxine.theme gxine.lang

%fdupes %buildroot

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING README
%dir %{_sysconfdir}/gxine
%config(noreplace) %{_sysconfdir}/gxine/*
%{_bindir}/gxin*
%lang(de) %{_mandir}/de/man1/*
%lang(es) %{_mandir}/es/man1/*
%{_mandir}/man1/*
%{_datadir}/applications/*
%{_datadir}/gxine
%{_datadir}/pixmaps/gxine*
%{_datadir}/icons/hicolor/*/apps/gxine.png

%files browser-plugin
%defattr(-,root,root)
%{_libdir}/browser-plugins/gxineplugin.*

%files lang -f gxine.lang

%changelog
* Fri Jun  2 2023 seife+obs@b1-systems.com
- add gxine-0.5.910-reproducible.diff to make desktop file
  consistent across xine build versions
* Fri Jul 13 2018 enzokiel@kabelmail.de
- Update to 0.5.910
  - Improve Gtk3 support. (still not enabled by default, use --with-gtk3).
  - Fix running under Wayland.
  - Improve portability.
  - Improve build system. Require automake 1.11.
  - Fix memory and resource leaks.
- Version 0.5.909
  - Dust removal. Support for recent glib and gtk+ versions.
  - Require glib 2.32 or later.
  - Require gtk+ 2.18 or later.
  - Portability improvements.
  - Linkage fixes.
  - #include fixes.
  - Fix memory and resource leaks.
  - Initial support for gtk+ 3.
  - Call XInitThreads even with XCB. (Fixes some video output methods.)
* Sat Aug 23 2014 joerg.lorenzen@ki.tng.de
- Update to 0.5.908
* Thu Feb  2 2012 Manfred Tremmel <Manfred.Tremmel@iiv.de> - 0.5.907-1
- Update to 0.5.907
* Fri Jan  6 2012 Manfred Tremmel <Manfred.Tremmel@iiv.de> - 0.5.906-2
- compile against libxine2
* Fri Aug 12 2011 Manfred Tremmel <Manfred.Tremmel@iiv.de> - 0.5.906-0.pm.0
- Update to 0.5.906
* Tue Feb 23 2010 Manfred Tremmel <Manfred.Tremmel@iiv.de> - 0.5.905-0.pm.2
- fixed desktop file
* Sat Jan  2 2010 Manfred Tremmel <Manfred.Tremmel@iiv.de> - 0.5.905-0.pm.1
- Update to 0.5.905
* Mon Dec 14 2009 Manfred Tremmel <Manfred.Tremmel@iiv.de> - 0.5.904-1.pm.3
- fixed wraper script when opening files with whitespaces
  [#290] in xine bugtracker
* Sun Sep 20 2009 Manfred Tremmel <Manfred.Tremmel@iiv.de> - 0.5.904-1.pm.2
- changes for openSUSE 11.2
* Sat Sep 12 2009 Manfred Tremmel <Manfred.Tremmel@iiv.de> - 0.5.904-1.pm.1
- cleanups where rpmlint wasn't so happy
* Sun Apr 19 2009 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- patch for lirc updated, can't only patch lirc.m4, because
  I can't run autogen.sh with older SUSE versions then 11.1.
  Now patched also configure out of a openSUSE 11.1 build run.
* Sat Apr 18 2009 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to 0.5.904
* Fri Jun 13 2008 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to 0.5.903
* Fri Apr 18 2008 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to 0.5.902
* Sun Mar  9 2008 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to 0.5.901
* Thu Mar  1 2007 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to 0.5.11
* Mon Dec 18 2006 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to 0.5.9
* Sat Nov 25 2006 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- some little changes for SUSE 10.2
* Sun Oct  8 2006 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to 0.5.8
* Wed Jul  5 2006 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to 0.5.7
* Wed May 17 2006 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- added wrapper script for SUSE 10.1 to find libmozjs.so
* Tue May  2 2006 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to 0.5.6
* Wed Mar  8 2006 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to 0.5.5
* Tue Jan 24 2006 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to 0.5.4
* Sun Dec 25 2005 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to 0.5.3
* Wed Dec 21 2005 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to 0.5.2
* Sat Dec  3 2005 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to 0.5.1
* Mon Oct 31 2005 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to 0.5.0
* Thu Jul 28 2005 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- excluded browser plugin into a subpackage
* Tue Jul 19 2005 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to 0.4.6
* Wed May 25 2005 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to 0.4.5
* Sun May  8 2005 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to 0.4.4
* Sat Apr  2 2005 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to 0.4.3
* Sat Apr  2 2005 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to 0.4.2
* Fri Dec 17 2004 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to 0.4.1
* Sun Dec 12 2004 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to 0.4.0
* Wed Apr  9 2003 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to 0.3.4
* Sun Mar 30 2003 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to 0.3.3
* Sun Mar 23 2003 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to 0.3.2
* Sun Mar  2 2003 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- little patch to compile on ppc
* Sat Mar  1 2003 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to gxine 0.3
* Thu Dec 26 2002 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to gxine 0.2.1
* Sat Dec  7 2002 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- Update to gxine 0.2
* Thu Dec  5 2002 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- initial release
